summaryrefslogtreecommitdiff
path: root/Lib/pickletools.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/pickletools.py')
-rw-r--r--Lib/pickletools.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/pickletools.py b/Lib/pickletools.py
index 8c324c70ba..f3e8fbce0a 100644
--- a/Lib/pickletools.py
+++ b/Lib/pickletools.py
@@ -1797,8 +1797,8 @@ def genops(pickle):
is None.
If the pickle has a tell() method, pos was the value of pickle.tell()
- before reading the current opcode. If the pickle is a string object,
- it's wrapped in a StringIO object, and the latter's tell() result is
+ before reading the current opcode. If the pickle is a bytes object,
+ it's wrapped in a BytesIO object, and the latter's tell() result is
used. Else (the pickle doesn't have a tell(), and it's not obvious how
to query its current position) pos is None.
"""